habitat.views.utils
===================

.. automodule:: habitat.views.utils

   
   
   .. rubric:: Functions

   .. autosummary::
   
      datetime_to_timestamp
      must_be_admin
      parse
      read_json_schema
      rfc3339_to_datetime
      rfc3339_to_timestamp
      rfc3339_to_utc_datetime
      timegm
      validate
      validate_doc
      validate_rfc3339
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      tzutc
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      ForbiddenError
      UnauthorizedError
      ValidationError
   
   